#ifndef GUARD_CODE_8099360_H
#define GUARD_CODE_8099360_H


bool8 sub_8099360(u8 *);
u8 sub_8099394(u8 *);
void sub_80993C0(bool8);
void sub_80993D8(void);
void sub_80993E4(void);

// UNUSED
void sub_80993F0(void);
// ------

void sub_8099648(void);
void nullsub_103(void);
void sub_809965C(void);

extern void sub_8099690(u32);

// code_8099360.s
extern void sub_8099A5C(u32, u32, u32);
extern void sub_8099AFC(u32, u32, u32);
extern bool8 sub_8099B94(void);

#endif //GUARD_CODE_8099360_H
